# fabdeb

Fabfile solutions for Debian Linux


## Running prepare web sever

Add to your fabfile.py:

    import fabfile
    
and you can run fabdeb.prepare_server command:
 
    # fab fabdeb.prepare_server
